@@ -1,6 +1,6 @@
 package Log::Log4perl::Tiny;
 {
-  $Log::Log4perl::Tiny::VERSION = '1.2.3';
+  $Log::Log4perl::Tiny::VERSION = '1.2.4';
 }
 
 # ABSTRACT: mimic Log::Log4perl in one single module
@@ -95,11 +95,27 @@ sub new {
 
    $args{format} = $args{layout} if exists $args{layout};
 
-   if (exists $args{file}) {
-      open my $fh, $args{file}
-        or die "open('$args{file}'): $!";
+   my $fh;
+   if (exists $args{file_append}) {
+      open $fh, '>>', $args{file_append}
+        or die "open('$args{file_append}') for appending: $!";
+   }
+   elsif (exists $args{file_create}) {
+      open $fh, '>', $args{file_create}
+        or die "open('$args{file_create}') for creating: $!";
+   }
+   else {
+      my $filename = exists $args{file_insecure} ? $args{file_insecure}
+                   : exists $args{file}          ? $args{file}
+                   :                               undef;
+      if (defined $filename) {
+         open $fh, $filename
+           or die "open('$filename'): $!";
+      }
+   }
 
-      # Autoflush opened file
+   # autoflush new filehandle and add to args if applicable
+   if (defined $fh) {
       my $previous = select($fh);
       $|++;
       select($previous);
@@ -130,8 +146,6 @@ sub format {
 
    if (@_) {
       $self->{format} = shift;
-      $self->{args}   = [];
-
       $self->{args} = \my @args;
       my $replace = sub {
          my ($num, $op) = @_;
@@ -282,8 +296,20 @@ sub _set_level_if_first {
 
 BEGIN {
 
+   # Time tracking's start time. Used to be tied to $^T but Log::Log4perl
+   # does differently and uses Time::HiRes if available
+   my $start_time = time(); # default, according to Log::Log4perl
+   my $has_time_hires;
+   eval {
+      require Time::HiRes;
+      $has_time_hires = 1;
+      $start_time = [ Time::HiRes::gettimeofday() ];
+   };
+
+   # For supporting %R
+   my $last_log = $start_time;
+
    # %format_for idea from Log::Tiny by J. M. Adler
-   my $last_log = $^T;
    %format_for = (    # specifiers according to Log::Log4perl
       c => [s => sub { 'main' }],
       C => [
@@ -362,8 +388,32 @@ BEGIN {
       n => [s => sub { "\n" },],
       p => [s => sub { $name_of{shift->{level}} },],
       P => [d => sub { $$ },],
-      r => [d => sub { time - $^T },],
-      R => [d => sub { my $l = $last_log; ($last_log = time) - $l; },],
+      r => [d => ( $has_time_hires # install sub depending on Time::HiRes
+         ?  sub {
+               my ($s, $m) = Time::HiRes::gettimeofday();
+               $s -= $start_time->[0];
+               $m = int(($m - $start_time->[1]) / 1000);
+               ($s, $m) = ($s - 1, $m + 1000) if $m < 0;
+               return $m + 1000 * $s;
+            }
+         :  sub {
+               return 1000 * (time() - $start_time);
+            }
+      ) ],
+      R => [d => ( $has_time_hires # install sub depending on Time::HiRes
+         ?  sub {
+               my ($sx, $mx) = Time::HiRes::gettimeofday();
+               my $s = $sx - $last_log->[0];
+               my $m = int(($mx - $last_log->[1]) / 1000);
+               ($s, $m) = ($s - 1, $m + 1000) if $m < 0;
+               $last_log = [ $sx, $mx ];
+               return $m + 1000 * $s;
+            }
+         :  sub {
+               my $l = $last_log;
+               return 1000 * (($last_log = time()) - $l);
+            }
+      ) ],
       T => [
          s => sub {
             my $level = 4;
@@ -431,22 +481,25 @@ BEGIN {
 
 1;                  # Magic true value required at end of module
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Log4perl::Tiny - mimic Log::Log4perl in one single module
 
 =head1 VERSION
 
-version 1.2.3
+version 1.2.4
 
 =head1 SYNOPSIS
 
    use Log::Log4perl::Tiny qw( :easy );
    Log::Log4perl->easy_init({
-      file   => '>>/var/log/something.log',
+      file   => '/var/log/something.log',
       layout => '[%d] [%-5P:%-5p] %m%n',
       level  => $INFO,
    });
@@ -680,6 +733,17 @@ the others will be ignored. The default value is C<$INFO>;
 a file name where to send the log lines. For compatibility with
 L<Log::Log4perl>, a 2-arguments C<open()> will be performed, which
 means you can easily set the opening mode, e.g. C<<< >>filename >>>.
+
+Note that the 2-arguments C<open()> is intrinsically insecure and will
+trigger the following error when running setuid:
+
+   Insecure dependency in open while running setuid
+
+so be sure to use either C<file_create> or C<file_append> instead if
+you're running setuid. These are extensions added by Log::Log4perl::Tiny
+to cope with this specific case (and also to allow you avoid the 2-args
+C<open()> anyway).
+
 The default is to send logging messages to C<STDERR>;
 
 =item C<< layout >>
@@ -698,6 +762,11 @@ If you call C<easy_init()> with a single unblessed scalar, it is
 considered to be the C<level> and it will be set accordingly.
 Otherwise, you have to pass a hash ref with the keys above.
 
+In addition to the above keys, the C<easy_init()> method installed
+by Log::Log4perl::Tiny also accepts all keys defined for L</new>, e.g.
+C<format> (an alias for C<layout>) and the different alternatives to
+C<file> (C<file_insecure>, C<file_create> and C<file_append>).
+
 =head2 Stealth Loggers
 
 Stealth loggers are functions that emit a log message at a given
@@ -821,6 +890,8 @@ that are modeled (with simplifications) after L<Log::Log4perl>'s ones:
     %P pid of the current process
     %r Number of milliseconds elapsed from program start to logging 
        event
+    %R Number of milliseconds elapsed from last logging event including
+       a %R to current logging event
     %% A literal percent (%) sign
 
 Notably, both C<%x> (NDC) and C<%X> (MDC) are missing. Moreover, the
@@ -921,12 +992,42 @@ following keys:
 
 =over
 
+=item B<< file >>
+
+=item B<< file_insecure >>
+
+=item B<< file_create >>
+
+=item B<< file_append >>
+
+set the file where log data should be sent. This option takes precedence
+over L</fh> below.
+
+The first one is kept for compliance with Log::Log4perl::easy_init's way
+of accepting a file. It eventually results in a two-arguments C<open()>
+call, so that you can quickly set how you want to open the file:
+
+   file => '>>/path/to/appended', # append mode
+   file => '>/path/to/new-file',  # create mode
+
+You should avoid doing this, because it is intrinsically insecure and will
+yield an error message when running setuid:
+
+   Insecure dependency in open while running setuid
+
+C<file_insecure> is an alias to C<file>, so that you can explicitly signal
+to the maintainer that you know what you're doing.
+
+C<file_create> and C<file_append> will use the three-arguments C<open()>
+call and thus they don't trigger the error above when running setuid. As
+the respective names suggest the former creates the file from scratch
+(possibly deleting any previous file with the same path) while the latter
+opens the file in append mode.
+
 =item B<< format >>
 
 =item B<< layout >>
 
-=item B<< file >>
-
 =item B<< level >>
 
 see L<< C<easy_init()> >> and the methods below with the same
@@ -1103,7 +1204,3 @@ but without any warranty; without even the implied warranty of
 merchantability or fitness for a particular purpose.
 
 =cut
-
-
-__END__
-
